==> 1.3.2.zip: g-earth/README.md <==
# G-Earth
Habbo packet logger & manipulator for Windows, Linux and Mac.

- Requires Java 8

[CLICK HERE FOR TROUBLESHOOTING](https://github.com/sirjonasxx/G-Earth/wiki/Troubleshooting)

Join the G-Earth [Discord server](https://discord.gg/AVkcF8y)

# Windows execution
Double click G-Earth.exe, which will be delivered in the release. Double clicking the .jar file might work as well.

# Linux execution
Execution command:
> $ java -jar G-Earth.jar 

Additionally, you can add the -t flag to log the packets in your terminal instead of opening a new window for it.

# Mac execution
[MacOs Installation guide](https://github.com/sirjonasxx/G-Earth/wiki/macOs-Installation-guide)

# Features
* Log outgoing and incoming packets
* Injection, both directions
* Blocking & replacing packets functionality
* Packet expressions
* Encoding/decoding
* Auto detect hotel
* Retro support - enter game host & port manually (only the first time)
* Advanced scheduler
* Advanced extension support
* Python scripting on the fly
* SOCKS proxy
* 2 included extensions on-release

Interested in creating an extension?
* If you're not experienced with Java but have written extensions before in C#, you could have a look at [Geode](https://github.com/ArachisH/Geode).
* If you are experienced with Java, read this [wiki page](https://github.com/sirjonasxx/G-Earth/wiki/Extensions) carefully.
* The easiest way to create extensions is using [G-Python](https://github.com/sirjonasxx/G-Python). (can also be done inside G-Earth with a [live scripting console](https://github.com/sirjonasxx/G-Earth/wiki/G-Python-qtConsole))

For the memorysearcher that extracts the RC4 table, go to [G-Mem](https://github.com/sirjonasxx/G-Mem).

==> 1.3.3.zip: g-earth/README.md <==
# G-Earth
Habbo packet logger & manipulator for Windows, Linux and Mac.

- Requires Java 8

[CLICK HERE FOR TROUBLESHOOTING](https://github.com/sirjonasxx/G-Earth/wiki/Troubleshooting)

Join the G-Earth [Discord server](https://discord.gg/AVkcF8y)

**Download the [chrome extension](https://chrome.google.com/webstore/detail/g-chrome/cdjgbghobmfmfcenhoahgfnfpcadddag) if you're using Unity**

# Windows execution
Double click G-Earth.exe, which will be delivered in the release. Double clicking the .jar file might work as well.

# Linux execution
Execution command:
> $ java -jar G-Earth.jar 

Additionally, you can add the -t flag to log the packets in your terminal instead of opening a new window for it.

# Mac execution
[MacOs Installation guide](https://github.com/sirjonasxx/G-Earth/wiki/macOs-Installation-guide) (flash only)

# Features
* Log outgoing and incoming packets
* Injection, both directions
* Blocking & replacing packets functionality
* Packet expressions
* Encoding/decoding
* Auto detect hotel
* Retro support - enter game host & port manually (only the first time)
* Advanced scheduler
* Advanced extension support
* Python scripting on the fly
* SOCKS proxy
* 2 included extensions on-release

Interested in creating an extension?
* If you're not experienced with Java but have written extensions before in C#, you could have a look at [Geode](https://github.com/ArachisH/Geode).
* If you are experienced with Java, read this [wiki page](https://github.com/sirjonasxx/G-Earth/wiki/Extensions) carefully.
* The easiest way to create extensions is using [G-Python](https://github.com/sirjonasxx/G-Python). (can also be done inside G-Earth with a [live scripting console](https://github.com/sirjonasxx/G-Earth/wiki/G-Python-qtConsole))

For the memorysearcher that extracts the RC4 table, go to [G-Mem](https://github.com/sirjonasxx/G-Mem).
